==> joss-0.9.14-sources.jar: org/javaswift/joss/command/impl/container/ListDirectoryCommandImpl.java <==
package org.javaswift.joss.command.impl.container;

import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.javaswift.joss.command.shared.container.ListDirectoryCommand;
import org.javaswift.joss.command.shared.container.StoredObjectListElement;
import org.javaswift.joss.instructions.ListInstructions;
import org.javaswift.joss.model.*;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class ListDirectoryCommandImpl extends AbstractListCommandImpl<Collection<DirectoryOrObject>> implements ListDirectoryCommand {

    private Character delimiter;

    public ListDirectoryCommandImpl(Account account, HttpClient httpClient, Access access, Container container,
                                    ListInstructions listInstructions, Character delimiter) {
        super(account, httpClient, access, container, listInstructions);
        this.delimiter = delimiter;
    }

    protected Collection<DirectoryOrObject> getReturnObject(HttpResponse response) throws IOException {

        StoredObjectListElement[] list = createObjectMapper(false)
                .readValue(response.getEntity().getContent(), StoredObjectListElement[].class);
        List<DirectoryOrObject> files = new ArrayList<DirectoryOrObject>();
        for (StoredObjectListElement header : list) {
            if (header.subdir != null) {
                files.add(new Directory(header.subdir, delimiter));
            } else {
                files.add(getStoredObject(header));
            }
        }
        return files;
    }

}

==> joss-0.10.4-sources.jar: org/javaswift/joss/command/impl/container/ListDirectoryCommandImpl.java <==
package org.javaswift.joss.command.impl.container;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.javaswift.joss.command.shared.container.ListDirectoryCommand;
import org.javaswift.joss.command.shared.container.StoredObjectListElement;
import org.javaswift.joss.instructions.ListInstructions;
import org.javaswift.joss.model.Access;
import org.javaswift.joss.model.Account;
import org.javaswift.joss.model.Container;
import org.javaswift.joss.model.Directory;
import org.javaswift.joss.model.DirectoryOrObject;

public class ListDirectoryCommandImpl extends AbstractListCommandImpl<Collection<DirectoryOrObject>> implements ListDirectoryCommand {

    private Character delimiter;

    public ListDirectoryCommandImpl(Account account, HttpClient httpClient, Access access, Container container,
                                    ListInstructions listInstructions, Character delimiter) {
        super(account, httpClient, access, container, listInstructions);
        this.delimiter = delimiter;
    }

    protected Collection<DirectoryOrObject> getReturnObject(HttpResponse response) throws IOException {

        StoredObjectListElement[] list = createObjectMapper(false)
                .readValue(response.getEntity().getContent(), StoredObjectListElement[].class);
        List<DirectoryOrObject> files = new ArrayList<DirectoryOrObject>();
        for (StoredObjectListElement header : list) {
            if (header.subdir != null) {
                files.add(new Directory(header.subdir, delimiter));
            } else {
                files.add(getStoredObject(header));
            }
        }
        return files;
    }

}
